.elementor-847 .elementor-element.elementor-element-4971f8eb{--display:flex;}.elementor-847 .elementor-element.elementor-element-4971f8eb.glozin-motion--sticky{position:var(--position);}@media(min-width:768px){.elementor-847 .elementor-element.elementor-element-4971f8eb{--content-width:1200px;}}