.elementor-1385 .elementor-element.elementor-element-3d753122{--display:flex;--min-height:380px;--flex-direction:column;--container-widget-width:calc( ( 1 - var( --container-widget-flex-grow ) ) * 100% );--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;--justify-content:center;--align-items:center;--gap:30px 30px;--row-gap:30px;--column-gap:30px;--overlay-opacity:0.4;--padding-top:30px;--padding-bottom:30px;--padding-left:30px;--padding-right:30px;}.elementor-1385 .elementor-element.elementor-element-3d753122.glozin-motion--sticky{position:var(--position);}.elementor-1385 .elementor-element.elementor-element-3d753122:not(.elementor-motion-effects-element-type-background), .elementor-1385 .elementor-element.elementor-element-3d753122 > .elementor-motion-effects-container > .elementor-motion-effects-layer{background-image:url("https://kidvite.shop/wp-content/uploads/2025/04/tiny_outfits-before-1.webp");background-position:center right;background-repeat:no-repeat;background-size:cover;}.elementor-1385 .elementor-element.elementor-element-3d753122::before, .elementor-1385 .elementor-element.elementor-element-3d753122 > .elementor-background-video-container::before, .elementor-1385 .elementor-element.elementor-element-3d753122 > .e-con-inner > .elementor-background-video-container::before, .elementor-1385 .elementor-element.elementor-element-3d753122 > .elementor-background-slideshow::before, .elementor-1385 .elementor-element.elementor-element-3d753122 > .e-con-inner > .elementor-background-slideshow::before, .elementor-1385 .elementor-element.elementor-element-3d753122 > .elementor-motion-effects-container > .elementor-motion-effects-layer::before{background-color:#0C0C0C;--background-overlay:'';}.elementor-1385 .elementor-element.elementor-element-1860aa5c .glozin-heading{justify-content:center;text-align:center;color:#FFFFFF;font-size:36px;line-height:44px;letter-spacing:-0.3px;}.elementor-1385 .elementor-element.elementor-element-20ec7a21 .glozin-button{min-width:250px;}.elementor-1385 .elementor-element.elementor-element-6e4c8f83 .glozin-heading{justify-content:center;text-align:center;color:#FFFFFF;}.elementor-1385 .elementor-element.elementor-element-204915a1{--display:flex;--gap:28px 28px;--row-gap:28px;--column-gap:28px;--padding-top:30px;--padding-bottom:30px;--padding-left:15px;--padding-right:15px;}.elementor-1385 .elementor-element.elementor-element-204915a1.glozin-motion--sticky{position:var(--position);}.elementor-1385 .elementor-element.elementor-element-26062a73 .glozin-heading{color:#020202;font-size:18px;font-weight:600;}.elementor-1385 .elementor-element.elementor-element-18fe10d7{--display:flex;--padding-top:0px;--padding-bottom:30px;--padding-left:15px;--padding-right:15px;}.elementor-1385 .elementor-element.elementor-element-18fe10d7.glozin-motion--sticky{position:var(--position);}.elementor-1385 .elementor-element.elementor-element-4f31e9f8 .glozin-button{min-width:100%;}@media(max-width:767px){.elementor-1385 .elementor-element.elementor-element-3d753122{--padding-top:30px;--padding-bottom:30px;--padding-left:30px;--padding-right:30px;}.elementor-1385 .elementor-element.elementor-element-20ec7a21 .glozin-button{min-width:220px;}}