.elementor-534 .elementor-element.elementor-element-73bb7f30{--display:flex;--flex-direction:row;--container-widget-width:initial;--container-widget-height:100%;--container-widget-flex-grow:1;--container-widget-align-self:stretch;--flex-wrap-mobile:wrap;--gap:140px 140px;--row-gap:140px;--column-gap:140px;--padding-top:55px;--padding-bottom:0px;--padding-left:0px;--padding-right:0px;}.elementor-534 .elementor-element.elementor-element-73bb7f30.glozin-motion--sticky{position:var(--position);}.elementor-534 .elementor-element.elementor-element-224e8905{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;--gap:3px 3px;--row-gap:3px;--column-gap:3px;}.elementor-534 .elementor-element.elementor-element-224e8905.glozin-motion--sticky{position:var(--position);}.elementor-534 .elementor-element.elementor-element-1953bb69 > .elementor-widget-container{padding:0px 0px 14px 0px;}.elementor-534 .elementor-element.elementor-element-1953bb69 .glozin-heading{font-size:24px;}.elementor-534 .elementor-element.elementor-element-107e0d15 > .elementor-widget-container{padding:0px 0px 17px 0px;}.elementor-534 .elementor-element.elementor-element-43091db3 > .elementor-widget-container{padding:0px 0px 2px 0px;}.elementor-534 .elementor-element.elementor-element-43091db3 .glozin-heading{font-size:16px;}.elementor-534 .elementor-element.elementor-element-35e30441 > .elementor-widget-container{padding:0px 0px 14px 0px;}.elementor-534 .elementor-element.elementor-element-73c4b02 .glozin-heading{font-size:16px;}.elementor-534 .elementor-element.elementor-element-7ce483bf > .elementor-widget-container{padding:0px 0px 30px 0px;}.elementor-534 .elementor-element.elementor-element-643c8143 .glozin-heading{font-size:16px;}.elementor-534 .elementor-element.elementor-element-18f0b61e{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;}.elementor-534 .elementor-element.elementor-element-18f0b61e.glozin-motion--sticky{position:var(--position);}.elementor-534 .elementor-element.elementor-element-2ad7058 .glozin-heading{font-size:24px;}.elementor-534 .elementor-element.elementor-element-647129d3 > .elementor-widget-container{padding:0px 0px 17px 0px;}@media(max-width:1024px){.elementor-534 .elementor-element.elementor-element-73bb7f30{--gap:30px 30px;--row-gap:30px;--column-gap:30px;}}@media(max-width:767px){.elementor-534 .elementor-element.elementor-element-73bb7f30{--gap:50px 50px;--row-gap:50px;--column-gap:50px;}}@media(min-width:768px){.elementor-534 .elementor-element.elementor-element-73bb7f30{--content-width:1200px;}.elementor-534 .elementor-element.elementor-element-224e8905{--width:35%;}.elementor-534 .elementor-element.elementor-element-18f0b61e{--width:65%;}}@media(max-width:1024px) and (min-width:768px){.elementor-534 .elementor-element.elementor-element-224e8905{--width:35%;}.elementor-534 .elementor-element.elementor-element-18f0b61e{--width:65%;}}