.elementor-1418 .elementor-element.elementor-element-7d1988b1{--display:flex;}.elementor-1418 .elementor-element.elementor-element-7d1988b1.glozin-motion--sticky{position:var(--position);}.elementor-1418 .elementor-element.elementor-element-7545a2cb .elementor-repeater-item-af2b4da{left:28%;--gz-shoppable-images-hotspot-x:-28%;top:34%;--gz-shoppable-images-hotspot-y:-34%;}.elementor-1418 .elementor-element.elementor-element-7545a2cb .elementor-repeater-item-0a28a5b{left:38%;--gz-shoppable-images-hotspot-x:-38%;top:70%;--gz-shoppable-images-hotspot-y:-70%;}.elementor-1418 .elementor-element.elementor-element-7545a2cb > .elementor-widget-container{margin:-1px -1px -1px -1px;}