.elementor-771 .elementor-element.elementor-element-d8d31b7{--display:flex;}.elementor-771 .elementor-element.elementor-element-d8d31b7.glozin-motion--sticky{position:var(--position);}.elementor-771 .elementor-element.elementor-element-fef20a0 .glozin-button{min-width:180px;}@media(min-width:768px){.elementor-771 .elementor-element.elementor-element-d8d31b7{--content-width:1410px;}}