.elementor-1690 .elementor-element.elementor-element-9ee7f80{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;}.elementor-1690 .elementor-element.elementor-element-9ee7f80.glozin-motion--sticky{position:var(--position);}.elementor-1690 .elementor-element.elementor-element-8b52f34{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;--gap:10px 10px;--row-gap:10px;--column-gap:10px;border-style:solid;--border-style:solid;border-width:1px 0px 0px 0px;--border-top-width:1px;--border-right-width:0px;--border-bottom-width:0px;--border-left-width:0px;border-color:#EBEBEB;--border-color:#EBEBEB;--padding-top:90px;--padding-bottom:0px;--padding-left:0px;--padding-right:0px;}.elementor-1690 .elementor-element.elementor-element-8b52f34.glozin-motion--sticky{position:var(--position);}.elementor-1690 .elementor-element.elementor-element-40fc356 .glozin-heading{justify-content:center;text-align:center;}.elementor-1690 .elementor-element.elementor-element-3b3c931 > .elementor-widget-container{padding:0px 0px 30px 0px;}.elementor-1690 .elementor-element.elementor-element-3b3c931 .glozin-heading{justify-content:center;text-align:center;}.elementor-1690 .elementor-element.elementor-element-8202c09{--display:flex;}.elementor-1690 .elementor-element.elementor-element-8202c09.glozin-motion--sticky{position:var(--position);}@media(min-width:768px){.elementor-1690 .elementor-element.elementor-element-9ee7f80{--content-width:1410px;}.elementor-1690 .elementor-element.elementor-element-8b52f34{--content-width:1410px;}}