.elementor-1516 .elementor-element.elementor-element-5efe4df9{--display:flex;}.elementor-1516 .elementor-element.elementor-element-5efe4df9.glozin-motion--sticky{position:var(--position);}.elementor-1516 .elementor-element.elementor-element-70c9f2a3 .elementor-repeater-item-af2b4da{left:44%;--gz-shoppable-images-hotspot-x:-44%;top:76%;--gz-shoppable-images-hotspot-y:-76%;}.elementor-1516 .elementor-element.elementor-element-70c9f2a3 .elementor-repeater-item-0a28a5b{left:55%;--gz-shoppable-images-hotspot-x:-55%;top:40%;--gz-shoppable-images-hotspot-y:-40%;}.elementor-1516 .elementor-element.elementor-element-70c9f2a3 > .elementor-widget-container{margin:-1px -1px -1px -1px;}