.elementor-1222 .elementor-element.elementor-element-c3efa27{--display:flex;}.elementor-1222 .elementor-element.elementor-element-c3efa27.glozin-motion--sticky{position:var(--position);}.elementor-1222 .elementor-element.elementor-element-7cd45d9 .glozin-categories-grid__items{--gz-categories-grid-columns:4;--gz-categories-grid-col-gap:30px;--gz-categories-grid-row-gap:30px;}.elementor-1222 .elementor-element.elementor-element-7cd45d9 .glozin-categories-grid__button{left:var(--gz-button-position-side);right:auto;transform:none;--gz-button-position-side:30px;}.elementor-1222 .elementor-element.elementor-element-7cd45d9 .glozin-categories-grid__button .glozin-button{font-size:22px;--gz-button-color:#FFFFFF;--gz-button-color-hover:#FFFFFF;}@media(max-width:1024px){.elementor-1222 .elementor-element.elementor-element-7cd45d9 .glozin-categories-grid__items{--gz-categories-grid-columns:3;--gz-categories-grid-col-gap:15px;--gz-categories-grid-row-gap:15px;}}@media(max-width:767px){.elementor-1222 .elementor-element.elementor-element-c3efa27{--flex-wrap:nowrap;}.elementor-1222 .elementor-element.elementor-element-7cd45d9 .glozin-categories-grid__items{--gz-categories-grid-columns:2;--gz-categories-grid-col-gap:15px;--gz-categories-grid-row-gap:15px;}.elementor-1222 .elementor-element.elementor-element-7cd45d9 .glozin-categories-grid__button{--gz-button-position-side:15px;bottom:15px;}.elementor-1222 .elementor-element.elementor-element-7cd45d9 .glozin-categories-grid__button .glozin-button{font-size:19px;}}