.elementor-1211 .elementor-element.elementor-element-ffb5a37{--display:flex;}.elementor-1211 .elementor-element.elementor-element-ffb5a37.glozin-motion--sticky{position:var(--position);}.elementor-1211 .elementor-element.elementor-element-27c8f06 .glozin-categories-grid__items{--gz-categories-grid-columns:4;--gz-categories-grid-col-gap:30px;--gz-categories-grid-row-gap:30px;}.elementor-1211 .elementor-element.elementor-element-27c8f06 .glozin-categories-grid__button{--gz-button-position-side:0px;}.elementor-1211 .elementor-element.elementor-element-27c8f06 .glozin-categories-grid__button .glozin-button{min-width:180px;}@media(max-width:1024px){.elementor-1211 .elementor-element.elementor-element-27c8f06 .glozin-categories-grid__items{--gz-categories-grid-columns:3;--gz-categories-grid-col-gap:15px;--gz-categories-grid-row-gap:15px;}}@media(max-width:767px){.elementor-1211 .elementor-element.elementor-element-ffb5a37{--flex-wrap:nowrap;}.elementor-1211 .elementor-element.elementor-element-27c8f06 .glozin-categories-grid__items{--gz-categories-grid-columns:2;--gz-categories-grid-col-gap:15px;--gz-categories-grid-row-gap:15px;}.elementor-1211 .elementor-element.elementor-element-27c8f06 .glozin-categories-grid__button .glozin-button{min-width:130px;}}