.elementor-574 .elementor-element.elementor-element-c3d42b3{--display:grid;--e-con-grid-template-columns:repeat(3, 1fr);--e-con-grid-template-rows:repeat(2, 1fr);--gap:50px 30px;--row-gap:50px;--column-gap:30px;--grid-auto-flow:row;}.elementor-574 .elementor-element.elementor-element-c3d42b3.glozin-motion--sticky{position:var(--position);}.elementor-574 .elementor-element.elementor-element-607aafad .glozin-image-box__image{margin-bottom:31px;}.elementor-574 .elementor-element.elementor-element-607aafad .glozin-image-box__title{font-size:20px;margin-bottom:6px;}.elementor-574 .elementor-element.elementor-element-607aafad .glozin-image-box__description{font-size:14px;}.elementor-574 .elementor-element.elementor-element-607aafad .glozin-button{min-width:180px;}.elementor-574 .elementor-element.elementor-element-6021246a .glozin-image-box__image{margin-bottom:31px;}.elementor-574 .elementor-element.elementor-element-6021246a .glozin-image-box__title{font-size:20px;margin-bottom:6px;}.elementor-574 .elementor-element.elementor-element-6021246a .glozin-image-box__description{font-size:14px;}.elementor-574 .elementor-element.elementor-element-6021246a .glozin-button{min-width:180px;}.elementor-574 .elementor-element.elementor-element-e7b5638 .glozin-image-box__image{margin-bottom:31px;}.elementor-574 .elementor-element.elementor-element-e7b5638 .glozin-image-box__title{font-size:20px;margin-bottom:6px;}.elementor-574 .elementor-element.elementor-element-e7b5638 .glozin-image-box__description{font-size:14px;}.elementor-574 .elementor-element.elementor-element-e7b5638 .glozin-button{min-width:180px;}.elementor-574 .elementor-element.elementor-element-23da48c .glozin-image-box__image{margin-bottom:31px;}.elementor-574 .elementor-element.elementor-element-23da48c .glozin-image-box__title{font-size:20px;margin-bottom:6px;}.elementor-574 .elementor-element.elementor-element-23da48c .glozin-image-box__description{font-size:14px;}.elementor-574 .elementor-element.elementor-element-23da48c .glozin-button{min-width:180px;}.elementor-574 .elementor-element.elementor-element-495da33b .glozin-image-box__image{margin-bottom:31px;}.elementor-574 .elementor-element.elementor-element-495da33b .glozin-image-box__title{font-size:20px;margin-bottom:6px;}.elementor-574 .elementor-element.elementor-element-495da33b .glozin-image-box__description{font-size:14px;}.elementor-574 .elementor-element.elementor-element-495da33b .glozin-button{min-width:180px;}.elementor-574 .elementor-element.elementor-element-6b8b7466 .glozin-image-box__image{margin-bottom:31px;}.elementor-574 .elementor-element.elementor-element-6b8b7466 .glozin-image-box__title{font-size:20px;margin-bottom:6px;}.elementor-574 .elementor-element.elementor-element-6b8b7466 .glozin-image-box__description{font-size:14px;}.elementor-574 .elementor-element.elementor-element-6b8b7466 .glozin-button{min-width:180px;}@media(min-width:768px){.elementor-574 .elementor-element.elementor-element-c3d42b3{--content-width:1410px;}}@media(max-width:1024px){.elementor-574 .elementor-element.elementor-element-c3d42b3{--e-con-grid-template-columns:repeat(2, 1fr);--grid-auto-flow:row;}}@media(max-width:767px){.elementor-574 .elementor-element.elementor-element-c3d42b3{--e-con-grid-template-columns:repeat(1, 1fr);--e-con-grid-template-rows:repeat(1, 1fr);--grid-auto-flow:row;}}