.elementor-1522 .elementor-element.elementor-element-2df4e1bc{--display:flex;}.elementor-1522 .elementor-element.elementor-element-2df4e1bc.glozin-motion--sticky{position:var(--position);}.elementor-1522 .elementor-element.elementor-element-268971b9 .elementor-repeater-item-af2b4da{left:30%;--gz-shoppable-images-hotspot-x:-30%;top:11%;--gz-shoppable-images-hotspot-y:-11%;}.elementor-1522 .elementor-element.elementor-element-268971b9 .elementor-repeater-item-0a28a5b{left:58%;--gz-shoppable-images-hotspot-x:-58%;top:77%;--gz-shoppable-images-hotspot-y:-77%;}.elementor-1522 .elementor-element.elementor-element-268971b9 > .elementor-widget-container{margin:-1px -1px -1px -1px;}