.elementor-695 .elementor-element.elementor-element-4cc8a2a4{--display:flex;}.elementor-695 .elementor-element.elementor-element-4cc8a2a4.glozin-motion--sticky{position:var(--position);}@media(min-width:768px){.elementor-695 .elementor-element.elementor-element-4cc8a2a4{--content-width:1410px;}}