.elementor-785 .elementor-element.elementor-element-6e826a98{--display:flex;}.elementor-785 .elementor-element.elementor-element-6e826a98.glozin-motion--sticky{position:var(--position);}@media(min-width:768px){.elementor-785 .elementor-element.elementor-element-6e826a98{--content-width:1410px;}}