.elementor-3172 .elementor-element.elementor-element-5c5912b3{--display:flex;--flex-direction:row;--container-widget-width:initial;--container-widget-height:100%;--container-widget-flex-grow:1;--container-widget-align-self:stretch;--flex-wrap-mobile:wrap;--gap:0px 0px;--row-gap:0px;--column-gap:0px;}.elementor-3172 .elementor-element.elementor-element-5c5912b3.glozin-motion--sticky{position:var(--position);}.elementor-3172 .elementor-element.elementor-element-5b1d7080{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;}.elementor-3172 .elementor-element.elementor-element-5b1d7080.glozin-motion--sticky{position:var(--position);}.elementor-3172 .elementor-element.elementor-element-18d0e7e7{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;--gap:10px 10px;--row-gap:10px;--column-gap:10px;}.elementor-3172 .elementor-element.elementor-element-18d0e7e7.glozin-motion--sticky{position:var(--position);}.elementor-widget-text-editor{font-family:var( --e-global-typography-text-font-family ), Sans-serif;font-weight:var( --e-global-typography-text-font-weight );color:var( --e-global-color-text );}.elementor-widget-text-editor.elementor-drop-cap-view-stacked .elementor-drop-cap{background-color:var( --e-global-color-primary );}.elementor-widget-text-editor.elementor-drop-cap-view-framed .elementor-drop-cap, .elementor-widget-text-editor.elementor-drop-cap-view-default .elementor-drop-cap{color:var( --e-global-color-primary );border-color:var( --e-global-color-primary );}.elementor-3172 .elementor-element.elementor-element-3ee8fb38{color:#111111;}.elementor-3172 .elementor-element.elementor-element-63275b84 > .elementor-widget-container{margin:15px 0px 0px 0px;}.elementor-3172 .elementor-element.elementor-element-2d57b92b{color:#111111;}.elementor-3172 .elementor-element.elementor-element-5a17749a > .elementor-widget-container{margin:-7px 0px 0px 0px;}.elementor-3172 .elementor-element.elementor-element-518c114{color:#111111;}.elementor-3172 .elementor-element.elementor-element-78e97c96 > .elementor-widget-container{margin:-7px 0px 0px 0px;}.elementor-3172 .elementor-element.elementor-element-2d0d9969{color:#111111;}.elementor-3172 .elementor-element.elementor-element-5b8fd142 > .elementor-widget-container{margin:-7px 0px 0px 0px;}.elementor-3172 .elementor-element.elementor-element-1f06f570{color:#111111;}.elementor-3172 .elementor-element.elementor-element-6e0e9afe > .elementor-widget-container{margin:15px 0px 0px 0px;}.elementor-3172 .elementor-element.elementor-element-142e6494{color:#111111;}.elementor-3172 .elementor-element.elementor-element-64eb6ae2 > .elementor-widget-container{margin:-7px 0px 0px 0px;}.elementor-3172 .elementor-element.elementor-element-1e192143{color:#111111;}.elementor-3172 .elementor-element.elementor-element-70d77215 > .elementor-widget-container{margin:15px 0px 0px 0px;}.elementor-3172 .elementor-element.elementor-element-56b848d8{color:#111111;}.elementor-3172 .elementor-element.elementor-element-3f2c4a42 > .elementor-widget-container{margin:15px 0px 0px 0px;}.elementor-3172 .elementor-element.elementor-element-9ee7414{color:#111111;}.elementor-3172 .elementor-element.elementor-element-7f1f66a2{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;}.elementor-3172 .elementor-element.elementor-element-7f1f66a2.glozin-motion--sticky{position:var(--position);}@media(max-width:1024px){.elementor-3172 .elementor-element.elementor-element-5c5912b3{--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;}}@media(min-width:768px){.elementor-3172 .elementor-element.elementor-element-5b1d7080{--width:25%;}.elementor-3172 .elementor-element.elementor-element-18d0e7e7{--width:50%;}.elementor-3172 .elementor-element.elementor-element-7f1f66a2{--width:25%;}}@media(max-width:1024px) and (min-width:768px){.elementor-3172 .elementor-element.elementor-element-5b1d7080{--width:100%;}.elementor-3172 .elementor-element.elementor-element-18d0e7e7{--width:100%;}}