.elementor-1508 .elementor-element.elementor-element-456006f2{--display:flex;}.elementor-1508 .elementor-element.elementor-element-456006f2.glozin-motion--sticky{position:var(--position);}.elementor-1508 .elementor-element.elementor-element-5f51cf51 .elementor-repeater-item-af2b4da{left:65%;--gz-shoppable-images-hotspot-x:-65%;top:46%;--gz-shoppable-images-hotspot-y:-46%;}.elementor-1508 .elementor-element.elementor-element-5f51cf51 .elementor-repeater-item-0a28a5b{left:40%;--gz-shoppable-images-hotspot-x:-40%;top:78%;--gz-shoppable-images-hotspot-y:-78%;}.elementor-1508 .elementor-element.elementor-element-5f51cf51 > .elementor-widget-container{margin:-1px -1px -1px -1px;}