.elementor-657 .elementor-element.elementor-element-409ae3a1{--display:flex;--flex-direction:row;--container-widget-width:initial;--container-widget-height:100%;--container-widget-flex-grow:1;--container-widget-align-self:stretch;--flex-wrap-mobile:wrap;--gap:50px 50px;--row-gap:50px;--column-gap:50px;}.elementor-657 .elementor-element.elementor-element-409ae3a1.glozin-motion--sticky{position:var(--position);}.elementor-657 .elementor-element.elementor-element-44348315{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;--gap:17px 17px;--row-gap:17px;--column-gap:17px;}.elementor-657 .elementor-element.elementor-element-44348315.glozin-motion--sticky{position:var(--position);}.elementor-657 .elementor-element.elementor-element-65a55c52{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;--gap:17px 17px;--row-gap:17px;--column-gap:17px;--border-radius:10px 10px 10px 10px;--padding-top:40px;--padding-bottom:40px;--padding-left:40px;--padding-right:40px;}.elementor-657 .elementor-element.elementor-element-65a55c52.glozin-motion--sticky{position:var(--position);}.elementor-657 .elementor-element.elementor-element-65a55c52:not(.elementor-motion-effects-element-type-background), .elementor-657 .elementor-element.elementor-element-65a55c52 > .elementor-motion-effects-container > .elementor-motion-effects-layer{background-color:#F5F5F5;}.elementor-657 .elementor-element.elementor-element-59bb03f3 .glozin-heading{font-size:24px;}.elementor-657 .elementor-element.elementor-element-2c67d14f .glozin-button{min-width:100%;--gz-button-bg-color:#FFFFFF;--gz-button-color:#111111;}.elementor-657 .elementor-element.elementor-element-13a336bb .glozin-button{min-width:100%;}.elementor-657 .elementor-element.elementor-element-457e5e1f{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;--gap:5px 5px;--row-gap:5px;--column-gap:5px;}.elementor-657 .elementor-element.elementor-element-457e5e1f.glozin-motion--sticky{position:var(--position);}.elementor-657 .elementor-element.elementor-element-1cc5379c .glozin-heading{font-size:24px;letter-spacing:-0.034em;}.elementor-657 .elementor-element.elementor-element-1bbb3159 > .elementor-widget-container{padding:45px 0px 0px 0px;}.elementor-657 .elementor-element.elementor-element-1bbb3159 .glozin-heading{font-size:24px;letter-spacing:-0.034em;}.elementor-657 .elementor-element.elementor-element-7425ce2d > .elementor-widget-container{padding:45px 0px 0px 0px;}.elementor-657 .elementor-element.elementor-element-7425ce2d .glozin-heading{font-size:24px;letter-spacing:-0.034em;}.elementor-657 .elementor-element.elementor-element-f31f690 > .elementor-widget-container{padding:45px 0px 0px 0px;}.elementor-657 .elementor-element.elementor-element-f31f690 .glozin-heading{font-size:24px;letter-spacing:-0.034em;}@media(min-width:768px){.elementor-657 .elementor-element.elementor-element-409ae3a1{--content-width:1200px;}.elementor-657 .elementor-element.elementor-element-44348315{--width:37%;}.elementor-657 .elementor-element.elementor-element-457e5e1f{--width:63%;}}@media(max-width:1024px){.elementor-657 .elementor-element.elementor-element-409ae3a1{--gap:30px 30px;--row-gap:30px;--column-gap:30px;}.elementor-657 .elementor-element.elementor-element-65a55c52{--padding-top:20px;--padding-bottom:20px;--padding-left:20px;--padding-right:20px;}}@media(max-width:767px){.elementor-657 .elementor-element.elementor-element-65a55c52{--padding-top:30px;--padding-bottom:30px;--padding-left:15px;--padding-right:15px;}.elementor-657 .elementor-element.elementor-element-457e5e1f{--padding-top:30px;--padding-bottom:0px;--padding-left:0px;--padding-right:0px;}}