.elementor-1502 .elementor-element.elementor-element-5805b495{--display:flex;}.elementor-1502 .elementor-element.elementor-element-5805b495.glozin-motion--sticky{position:var(--position);}.elementor-1502 .elementor-element.elementor-element-7ce07cfa .elementor-repeater-item-af2b4da{left:29%;--gz-shoppable-images-hotspot-x:-29%;top:11%;--gz-shoppable-images-hotspot-y:-11%;}.elementor-1502 .elementor-element.elementor-element-7ce07cfa .elementor-repeater-item-0a28a5b{left:74%;--gz-shoppable-images-hotspot-x:-74%;top:59%;--gz-shoppable-images-hotspot-y:-59%;}.elementor-1502 .elementor-element.elementor-element-7ce07cfa > .elementor-widget-container{margin:-1px -1px -1px -1px;}