.elementor-3367 .elementor-element.elementor-element-8483fa5{--display:flex;--flex-direction:row;--container-widget-width:initial;--container-widget-height:100%;--container-widget-flex-grow:1;--container-widget-align-self:stretch;--flex-wrap-mobile:wrap;--gap:0px 0px;--row-gap:0px;--column-gap:0px;}.elementor-3367 .elementor-element.elementor-element-8483fa5.glozin-motion--sticky{position:var(--position);}.elementor-3367 .elementor-element.elementor-element-e86bde8{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;}.elementor-3367 .elementor-element.elementor-element-e86bde8.glozin-motion--sticky{position:var(--position);}.elementor-3367 .elementor-element.elementor-element-82b855d{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;--gap:10px 10px;--row-gap:10px;--column-gap:10px;}.elementor-3367 .elementor-element.elementor-element-82b855d.glozin-motion--sticky{position:var(--position);}.elementor-widget-text-editor{font-family:var( --e-global-typography-text-font-family ), Sans-serif;font-weight:var( --e-global-typography-text-font-weight );color:var( --e-global-color-text );}.elementor-widget-text-editor.elementor-drop-cap-view-stacked .elementor-drop-cap{background-color:var( --e-global-color-primary );}.elementor-widget-text-editor.elementor-drop-cap-view-framed .elementor-drop-cap, .elementor-widget-text-editor.elementor-drop-cap-view-default .elementor-drop-cap{color:var( --e-global-color-primary );border-color:var( --e-global-color-primary );}.elementor-3367 .elementor-element.elementor-element-15ef96f{color:#111111;}.elementor-3367 .elementor-element.elementor-element-40d24e1 > .elementor-widget-container{margin:15px 0px 0px 0px;}.elementor-3367 .elementor-element.elementor-element-243b7f2{color:#111111;}.elementor-3367 .elementor-element.elementor-element-a1b707a > .elementor-widget-container{margin:15px 0px 0px 0px;}.elementor-3367 .elementor-element.elementor-element-41cc1d7{color:#111111;}.elementor-3367 .elementor-element.elementor-element-a705087 > .elementor-widget-container{margin:-7px 0px 0px 0px;}.elementor-3367 .elementor-element.elementor-element-87b3dea{color:#111111;}.elementor-3367 .elementor-element.elementor-element-2ea2323 > .elementor-widget-container{margin:-7px 0px 0px 0px;}.elementor-3367 .elementor-element.elementor-element-ebde9a7{color:#111111;}.elementor-3367 .elementor-element.elementor-element-13e7869 > .elementor-widget-container{margin:-7px 0px 0px 0px;}.elementor-3367 .elementor-element.elementor-element-b784d4c{color:#111111;}.elementor-3367 .elementor-element.elementor-element-cb4134e > .elementor-widget-container{margin:-7px 0px 0px 0px;}.elementor-3367 .elementor-element.elementor-element-bb70675{color:#111111;}.elementor-3367 .elementor-element.elementor-element-37b1f04 > .elementor-widget-container{margin:-7px 0px 0px 0px;}.elementor-3367 .elementor-element.elementor-element-8f1a776{color:#111111;}.elementor-3367 .elementor-element.elementor-element-0d83726 > .elementor-widget-container{margin:-7px 0px 0px 0px;}.elementor-3367 .elementor-element.elementor-element-4d8015d{color:#111111;}.elementor-3367 .elementor-element.elementor-element-2961ce8{--display:flex;--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;}.elementor-3367 .elementor-element.elementor-element-2961ce8.glozin-motion--sticky{position:var(--position);}@media(max-width:1024px){.elementor-3367 .elementor-element.elementor-element-8483fa5{--flex-direction:column;--container-widget-width:100%;--container-widget-height:initial;--container-widget-flex-grow:0;--container-widget-align-self:initial;--flex-wrap-mobile:wrap;}}@media(min-width:768px){.elementor-3367 .elementor-element.elementor-element-e86bde8{--width:25%;}.elementor-3367 .elementor-element.elementor-element-82b855d{--width:50%;}.elementor-3367 .elementor-element.elementor-element-2961ce8{--width:25%;}}@media(max-width:1024px) and (min-width:768px){.elementor-3367 .elementor-element.elementor-element-e86bde8{--width:100%;}.elementor-3367 .elementor-element.elementor-element-82b855d{--width:100%;}}