.elementor-1527 .elementor-element.elementor-element-9ea3c51{--display:flex;}.elementor-1527 .elementor-element.elementor-element-9ea3c51.glozin-motion--sticky{position:var(--position);}.elementor-1527 .elementor-element.elementor-element-2d93f214 .elementor-repeater-item-af2b4da{left:30%;--gz-shoppable-images-hotspot-x:-30%;top:72%;--gz-shoppable-images-hotspot-y:-72%;}.elementor-1527 .elementor-element.elementor-element-2d93f214 .elementor-repeater-item-0a28a5b{left:74%;--gz-shoppable-images-hotspot-x:-74%;top:88%;--gz-shoppable-images-hotspot-y:-88%;}.elementor-1527 .elementor-element.elementor-element-2d93f214 > .elementor-widget-container{margin:-1px -1px -1px -1px;}