.elementor-3247 .elementor-element.elementor-element-be0ce04{--display:flex;--flex-direction:row;--container-widget-width:initial;--container-widget-height:100%;--container-widget-flex-grow:1;--container-widget-align-self:stretch;--flex-wrap-mobile:wrap;--justify-content:space-between;--gap:0px 10px;--row-gap:0px;--column-gap:10px;--flex-wrap:nowrap;--overflow:auto;box-shadow:5px 0px 30px 0px rgba(0, 0, 0, 0.08);--padding-top:13px;--padding-bottom:12px;--padding-left:20px;--padding-right:20px;}.elementor-3247 .elementor-element.elementor-element-be0ce04.glozin-motion--sticky{position:var(--position);}@media(max-width:767px){.elementor-3247 .elementor-element.elementor-element-be0ce04{--flex-wrap:nowrap;}}